@@ -446,21 +446,20 @@ static int ap_hook_call_func(va_list ap, ap_hook_entry *he, ap_hook_func *hf)
      *
      * 3. Actually currently used hooks.
      *
-     *    int   func(ptr,ptr,int)              e.g. ap::buff::read [http_main.c]
-     *    int   func(ptr,ptr,int)              e.g. ap::buff::write [http_main.c]
-     *    int   func(ptr,ptr,int)              e.g. ap::buff::writev [http_main.c]
-     *    int   func(ptr,ptr,int)              e.g. ap::buff::sendwithtimeout [http_main.c]
-     *    int   func(ptr,ptr,int)              e.g. ap::buff::recvwithtimeout [http_main.c]
-     *    int   func(ptr,ptr)                  e.g. ap::mod_proxy::canon [mod_proxy.c]
-     *    int   func(ptr,ptr,ptr,int)          e.g. ap::mod_proxy::http::canon [mod_proxy.c]
-     *    int   func(ptr,ptr,ptr,ptr,int)      e.g. ap::mod_proxy::http::handler [mod_proxy.c]
-     *    int   func(ptr,ptr)                  e.g. ap::mod_proxy::error [mod_proxy.c]
-     *    int   func(ptr,ptr,ptr,ptr,int,ptr)  e.g. ap::mod_proxy::handler [mod_proxy.c]
-     *    int   func(ptr)                      e.g. ap::mod_proxy::http::handler::set_destport [proxy_http.c]
-     *    ptr   func(ptr,ptr)                  e.g. ap::mod_proxy::http::handler::new_connection [proxy_http.c]
-     *    int   func(ptr,ptr,ptr,int,ptr)      e.g. ap::mod_proxy::http::handler::write_host_header [proxy_http.c]
-     *    ptr   func(ptr,ptr,ptr,ptr,ptr)      e.g. ap::mod_ssl::var_lookup [ssl_engine_vars.c]
-     *    ptr   func(ptr,ptr)                  e.g. ap::mod_rewrite::lookup_variable [mod_rewrite.c]
+     *    int   func(ptr)                          [2x]
+     *    int   func(ptr,ptr)                      [2x]
+     *    int   func(ptr,ptr,int)                  [5x]
+     *    int   func(ptr,ptr,ptr,int)              [1x]
+     *    int   func(ptr,ptr,ptr,int,ptr)          [1x]
+     *    int   func(ptr,ptr,ptr,ptr,int)          [1x]
+     *    int   func(ptr,ptr,ptr,ptr,int,ptr)      [1x]
+     *    ptr   func(ptr,ptr)                      [3x]
+     *    ptr   func(ptr,ptr,ptr,ptr,ptr)          [1x]
+     *    void  func(ptr)                          [2x]
+     *    void  func(ptr,int,int)                  [1x]
+     *    void  func(ptr,ptr)                      [5x]
+     *    void  func(ptr,ptr,ptr)                  [3x]
+     *    void  func(ptr,ptr,ptr,ptr)              [2x]
      *
      * To simplify the programming task we generate the actual dispatch code
      * for these calls via the embedded Perl script at the end of this source
@@ -729,6 +728,16 @@ static int ap_hook_call_func(va_list ap, ap_hook_entry *he, ap_hook_func *hf)
         *((int *)v_rc) = ((int(*)(void *, void *, void *, int))(hf->hf_ptr))(v1, v2, v3, v4);
         rc = (*((int *)v_rc) != he->he_modeval.v_int);
     }
+    else if (he->he_sig == AP_HOOK_SIG6(int, ptr, ptr, ptr, int, ptr)) {
+        /* Call: int func(ptr,ptr,ptr,int,ptr) */
+        void *v1 = va_arg(ap, va_type(ptr));
+        void *v2 = va_arg(ap, va_type(ptr));
+        void *v3 = va_arg(ap, va_type(ptr));
+        int   v4 = va_arg(ap, va_type(int));
+        void *v5 = va_arg(ap, va_type(ptr));
+        *((int *)v_rc) = ((int(*)(void *, void *, void *, int, void *))(hf->hf_ptr))(v1, v2, v3, v4, v5);
+        rc = (*((int *)v_rc) != he->he_modeval.v_int);
+    }
     else if (he->he_sig == AP_HOOK_SIG6(int, ptr, ptr, ptr, ptr, int)) {
         /* Call: int func(ptr,ptr,ptr,ptr,int) */
         void *v1 = va_arg(ap, va_type(ptr));
@@ -750,16 +759,6 @@ static int ap_hook_call_func(va_list ap, ap_hook_entry *he, ap_hook_func *hf)
         *((int *)v_rc) = ((int(*)(void *, void *, void *, void *, int, void *))(hf->hf_ptr))(v1, v2, v3, v4, v5, v6);
         rc = (*((int *)v_rc) != he->he_modeval.v_int);
     }
-    else if (he->he_sig == AP_HOOK_SIG6(int, ptr, ptr, ptr, int, ptr)) {
-        /* Call: int func(ptr,ptr,ptr,int,ptr) */
-        void *v1 = va_arg(ap, va_type(ptr));
-        void *v2 = va_arg(ap, va_type(ptr));
-        void *v3 = va_arg(ap, va_type(ptr));
-        int   v4 = va_arg(ap, va_type(int));
-        void *v5 = va_arg(ap, va_type(ptr));
-        *((int *)v_rc) = ((int(*)(void *, void *, void *, int, void *))(hf->hf_ptr))(v1, v2, v3, v4, v5);
-        rc = (*((int *)v_rc) != he->he_modeval.v_int);
-    }
     else if (he->he_sig == AP_HOOK_SIG6(ptr, ptr, ptr, ptr, ptr, ptr)) {
         /* Call: ptr func(ptr,ptr,ptr,ptr,ptr) */
         void *v1 = va_arg(ap, va_type(ptr));
@@ -770,11 +769,38 @@ static int ap_hook_call_func(va_list ap, ap_hook_entry *he, ap_hook_func *hf)
         *((void * *)v_rc) = ((void *(*)(void *, void *, void *, void *, void *))(hf->hf_ptr))(v1, v2, v3, v4, v5);
         rc = (*((void * *)v_rc) != he->he_modeval.v_ptr);
     }
-    else if (he->he_sig == AP_HOOK_SIG2(ptr, char)) {
-        /* Call: ptr func(char) */
-        char  v1 = va_arg(ap, va_type(char));
-        *((void * *)v_rc) = ((void *(*)(char))(hf->hf_ptr))(v1);
-        rc = (*((void * *)v_rc) != he->he_modeval.v_ptr);
+    else if (he->he_sig == AP_HOOK_SIG2(void, ptr)) {
+        /* Call: void func(ptr) */
+        void *v1 = va_arg(ap, va_type(ptr));
+        ((void(*)(void *))(hf->hf_ptr))(v1);
+    }
+    else if (he->he_sig == AP_HOOK_SIG4(void, ptr, int, int)) {
+        /* Call: void func(ptr,int,int) */
+        void *v1 = va_arg(ap, va_type(ptr));
+        int   v2 = va_arg(ap, va_type(int));
+        int   v3 = va_arg(ap, va_type(int));
+        ((void(*)(void *, int, int))(hf->hf_ptr))(v1, v2, v3);
+    }
+    else if (he->he_sig == AP_HOOK_SIG3(void, ptr, ptr)) {
+        /* Call: void func(ptr,ptr) */
+        void *v1 = va_arg(ap, va_type(ptr));
+        void *v2 = va_arg(ap, va_type(ptr));
+        ((void(*)(void *, void *))(hf->hf_ptr))(v1, v2);
+    }
+    else if (he->he_sig == AP_HOOK_SIG4(void, ptr, ptr, ptr)) {
+        /* Call: void func(ptr,ptr,ptr) */
+        void *v1 = va_arg(ap, va_type(ptr));
+        void *v2 = va_arg(ap, va_type(ptr));
+        void *v3 = va_arg(ap, va_type(ptr));
+        ((void(*)(void *, void *, void *))(hf->hf_ptr))(v1, v2, v3);
+    }
+    else if (he->he_sig == AP_HOOK_SIG5(void, ptr, ptr, ptr, ptr)) {
+        /* Call: void func(ptr,ptr,ptr,ptr) */
+        void *v1 = va_arg(ap, va_type(ptr));
+        void *v2 = va_arg(ap, va_type(ptr));
+        void *v3 = va_arg(ap, va_type(ptr));
+        void *v4 = va_arg(ap, va_type(ptr));
+        ((void(*)(void *, void *, void *, void *))(hf->hf_ptr))(v1, v2, v3, v4);
     }
     /* ----END GENERATED SECTION---------- */
     else
@@ -806,6 +832,7 @@ my $end   = '----END GENERATED SECTION----------';
 if ($ARGV[0] eq 'used') {
     my @S = `find .. -type f -name "*.c" -print`;
     my $s;
+    my %T = ();
     foreach $s (@S) {
         $s =~ s|\n$||;
         open(FP, "<$s") || die;
@@ -820,10 +847,15 @@ if ($ARGV[0] eq 'used') {
             my ($rc, $args) = ($sig =~ m|^([^,]+)(.*)$|);
             $args =~ s|^,||;
             $src =~ s|^.+/||;
-            printf("     *    %-6s%-30s e.g. %s [%s]\n", $rc, "func($args)", $hook, $src);
+            my $sig = sprintf("%-6sfunc(%s)", $rc, $args);
+            $T{$sig}++; 
         }
         $source =~ s|\("([^"]+)",\s*AP_HOOK_SIG[0-9]\((.+?)\)|&printme($s, $1, $2), ''|sge;
     }
+    my $t;
+    foreach $t (sort(keys(%T))) {
+        printf("     *    %-40s [%dx]\n", $t, $T{$t});
+    }
     exit(0);
 }
 
