@@ -439,7 +439,8 @@ typedef struct {
     pool           *pPool;
     BOOL            bFixed;
     int             nInitCount;
-    RSA            *pRSATmpKey;
+    RSA            *pRSATmpKey512;
+    RSA            *pRSATmpKey1024;
     int             nSessionCacheMode;
     char           *szSessionCacheDataFile;
     ssl_mutexmode_t nMutexMode;
@@ -546,7 +547,7 @@ const char  *ssl_cmd_SSLRequire(cmd_parms *, SSLDirConfigRec *, char *);
 
 /*  module initialization  */
 void         ssl_init_Module(server_rec *, pool *);
-void         ssl_init_SSLLibrary(server_rec *);
+void         ssl_init_SSLLibrary(void);
 void         ssl_init_GetCertAndKey(server_rec *, pool *, SSLSrvConfigRec *);
 STACK       *ssl_init_FindCAList(server_rec *, pool *, char *, char *);
 void         ssl_init_Child(server_rec *, pool *);
