@@ -156,6 +156,18 @@ void ssl_init_Module(server_rec *s, pool *p)
         ssl_log_open(s2, p);
     }
 
+    /* 
+     * Identification
+     */
+    if (mc->nInitCount == 1)
+        ssl_log(s, SSL_LOG_INFO, "Server: %s, Interface: %s, Library: %s",
+                SERVER_BASEVERSION,
+                ssl_var_lookup(p, NULL, NULL, NULL, "SSL_VERSION_INTERFACE"),
+                ssl_var_lookup(p, NULL, NULL, NULL, "SSL_VERSION_LIBRARY"));
+
+    /* 
+     * Initialization round information
+     */
     if (mc->nInitCount == 1)
         ssl_log(s, SSL_LOG_INFO, "Init: 1st startup round (still not detached)");
     else if (mc->nInitCount == 2)
@@ -165,7 +177,7 @@ void ssl_init_Module(server_rec *s, pool *p)
                 mc->nInitCount-2, (mc->nInitCount-2) == 1 ? "st" : "nd");
 
 #ifdef SSL_VENDOR
-    ap_hook_use("ssl::vendor::init_module", 
+    ap_hook_use("ap::mod_ssl::vendor::init_module", 
                 AP_HOOK_SIG3(void,ptr,ptr), AP_HOOK_ALL, s, p);
 #endif
 
@@ -205,10 +217,15 @@ void ssl_init_Module(server_rec *s, pool *p)
      */
 
 #ifdef SHARED_MODULE
-    ssl_init_SSLLibrary(s);
+    ssl_log(s, SSL_LOG_INFO, "Init: %snitializing %s library", 
+            mc->nInitCount == 1 ? "I" : "Rei", SSL_LIBRARY_NAME);
+    ssl_init_SSLLibrary();
 #else
-    if (mc->nInitCount <= 2)
-        ssl_init_SSLLibrary(s);
+    if (mc->nInitCount <= 2) {
+        ssl_log(s, SSL_LOG_INFO, "Init: %snitializing %s library", 
+                mc->nInitCount == 1 ? "I" : "Rei", SSL_LIBRARY_NAME);
+        ssl_init_SSLLibrary();
+    }
 #endif
     if (mc->nInitCount == 1) {
         ssl_pphrase_Handle(s, p);
@@ -240,13 +257,18 @@ void ssl_init_Module(server_rec *s, pool *p)
     ssl_log(s, SSL_LOG_INFO, "Init: Seeding PRNG with %d bytes of entropy", n);
 
     /*
-     *  pre-generate the temporary RSA key
+     *  pre-generate the temporary RSA keys
      */
-    if (mc->pRSATmpKey == NULL) {
-        ssl_log(s, SSL_LOG_INFO, "Init: Generating temporary (512 bit) RSA private key");
-        mc->pRSATmpKey = RSA_generate_key(512, RSA_F4, NULL, NULL);
-        if (mc->pRSATmpKey == NULL) {
-            ssl_log(s, SSL_LOG_ERROR, "Init: Failed to generate temporary (512 bit) RSA private key");
+    if (mc->pRSATmpKey512 == NULL) {
+        ssl_log(s, SSL_LOG_INFO, "Init: Generating temporary RSA private keys");
+        mc->pRSATmpKey512 = RSA_generate_key(512, RSA_F4, NULL, NULL);
+        if (mc->pRSATmpKey512 == NULL) {
+            ssl_log(s, SSL_LOG_ERROR, "Init: Failed to generate temporary 512 bit RSA private key");
+            ssl_die();
+        }
+        mc->pRSATmpKey1024 = RSA_generate_key(1024, RSA_F4, NULL, NULL);
+        if (mc->pRSATmpKey1024 == NULL) {
+            ssl_log(s, SSL_LOG_ERROR, "Init: Failed to generate temporary 1024 bit RSA private key");
             ssl_die();
         }
     }
@@ -303,9 +325,8 @@ void ssl_init_Module(server_rec *s, pool *p)
 /*
  *  Initialize SSL library (also already needed for the pass phrase dialog)
  */
-void ssl_init_SSLLibrary(server_rec *s)
+void ssl_init_SSLLibrary(void)
 {
-    ssl_log(s, SSL_LOG_INFO, "Init: Initializing %s library", SSL_LIBRARY_NAME);
 #ifdef WIN32
     CRYPTO_malloc_init();
 #endif
