@@ -175,6 +175,10 @@ void ssl_hook_NewConnection(conn_rec *conn)
      * so we can detach later.
      */
     ssl = SSL_new(sc->pSSLCtx);
+    SSL_clear(ssl);
+#if SSL_LIBRARY_VERSION >= 0x0922
+    SSL_set_session_id_context(ssl, cpVHostID, strlen(cpVHostID));
+#endif
     SSL_set_app_data(ssl, conn);  /* conn_rec    (available now)     */
     SSL_set_app_data2(ssl, NULL); /* request_rec (available later)   */
     SSL_set_fd(ssl, fb->fd);
@@ -410,7 +414,7 @@ void ssl_hook_NewConnection(conn_rec *conn)
 
 #ifdef SSL_VENDOR
     /* Allow vendors to do more things on connection time... */
-    ap_hook_use("ssl::vendor::new_connection", 
+    ap_hook_use("ap::mod_ssl::vendor::new_connection", 
                 AP_HOOK_SIG2(void,ptr), AP_HOOK_ALL, conn);
 #endif
 
@@ -904,7 +908,7 @@ int ssl_hook_Access(request_rec *r)
      */
     rc = OK;
 #ifdef SSL_VENDOR
-    ap_hook_use("ssl::vendor::access_handler", 
+    ap_hook_use("ap::mod_ssl::vendor::access_handler", 
                 AP_HOOK_SIG2(int,ptr), AP_HOOK_DECLINE(DECLINED), 
                 &rc, r);
 #endif
@@ -1026,7 +1030,38 @@ int ssl_hook_Fixup(request_rec *r)
 */
 
 /*
- * Handle out the already generated RSA key...
+ * Handle out temporary RSA private keys on demand
+ *
+ * The background of this as the TLSv1 standard explains it:
+ *
+ * | D.1. Temporary RSA keys
+ * | 
+ * |    US Export restrictions limit RSA keys used for encryption to 512
+ * |    bits, but do not place any limit on lengths of RSA keys used for
+ * |    signing operations. Certificates often need to be larger than 512
+ * |    bits, since 512-bit RSA keys are not secure enough for high-value
+ * |    transactions or for applications requiring long-term security. Some
+ * |    certificates are also designated signing-only, in which case they
+ * |    cannot be used for key exchange.
+ * | 
+ * |    When the public key in the certificate cannot be used for encryption,
+ * |    the server signs a temporary RSA key, which is then exchanged. In
+ * |    exportable applications, the temporary RSA key should be the maximum
+ * |    allowable length (i.e., 512 bits). Because 512-bit RSA keys are
+ * |    relatively insecure, they should be changed often. For typical
+ * |    electronic commerce applications, it is suggested that keys be
+ * |    changed daily or every 500 transactions, and more often if possible.
+ * |    Note that while it is acceptable to use the same temporary key for
+ * |    multiple transactions, it must be signed each time it is used.
+ * | 
+ * |    RSA key generation is a time-consuming process. In many cases, a
+ * |    low-priority process can be assigned the task of key generation.
+ * |    Whenever a new key is completed, the existing temporary key can be
+ * |    replaced with the new one.
+ *
+ * So we generated 512 and 1024 bit temporary keys on startup
+ * which we now just handle out on demand....
+ *
  */
 #if SSL_LIBRARY_VERSION >= 0x0920
 RSA *ssl_callback_TmpRSA(SSL *pSSL, int nExport, int nKeyLen)
@@ -1035,8 +1070,31 @@ RSA *ssl_callback_TmpRSA(SSL *pSSL, int nExport)
 #endif
 {
     SSLModConfigRec *mc = myModConfig();
+    RSA *rsa;
 
-    return mc->pRSATmpKey;
+    rsa = NULL;
+#if SSL_LIBRARY_VERSION >= 0x0920
+    if (nExport) {
+        /* It's because an export cipher is used */
+        if (nKeyLen == 512)
+            rsa = mc->pRSATmpKey512;
+        else if (nKeyLen == 1024)
+            rsa = mc->pRSATmpKey1024;
+        else
+            /* it's too expensive to generate on-the-fly, so keep 1024bit */
+            rsa = mc->pRSATmpKey1024;
+    }
+    else {
+        /* It's because a sign-only certificate situation exists */
+        rsa = mc->pRSATmpKey1024;
+    }
+#else
+    if (nExport)
+        rsa = mc->pRSATmpKey512;
+    else
+        rsa = mc->pRSATmpKey1024;
+#endif
+    return rsa;
 }
 
 /*
