@@ -136,8 +136,7 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
                     "Init: Can't open server certificate file %s", szPath);
             ssl_die();
         }
-        pX509Cert = X509_new();
-        if (!PEM_read_X509(fp, &pX509Cert, NULL)) {
+        if ((pX509Cert = SSL_read_X509(fp, NULL, NULL)) == NULL) {
             ssl_log(s, SSL_LOG_ERROR|SSL_ADD_SSLERR,
                     "Init: Unable to read server certificate from file %s", szPath);
             ssl_die();
@@ -194,7 +193,6 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
         myCtxVarSet(mc, 8, &nPassPhraseDialogCur);
         myCtxVarSet(mc, 9, &bPassPhraseDialogOnce);
 
-        pRSAKey = RSA_new();
         nPassPhraseCur        = 0;
         nPassPhraseRetry      = 0;
         nPassPhraseDialogCur  = 0;
@@ -212,8 +210,8 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
                 ssl_die();
             }
             cpPassPhraseCur = NULL;
-            bReadable = (PEM_read_RSAPrivateKey(fp, &pRSAKey,
-                         ssl_pphrase_Handle_CB) ? TRUE : FALSE);
+            bReadable = ((pRSAKey = SSL_read_RSAPrivateKey(fp, NULL,
+                         ssl_pphrase_Handle_CB)) != NULL ? TRUE : FALSE);
             ap_pfclose(p, fp);
 
             /*
