@@ -87,7 +87,7 @@ void ssl_scache_init(server_rec *s, pool *p)
     ssl_scache_expire(s);
 
 #ifdef SSL_VENDOR
-    ap_hook_use("ssl::vendor::scache_init", 
+    ap_hook_use("ap::mod_ssl::vendor::scache_init", 
                 AP_HOOK_SIG3(void,ptr,ptr), AP_HOOK_ALL, s, p);
 #endif
 
@@ -115,7 +115,7 @@ void ssl_scache_store(server_rec *s, SSL_SESSION *pSession, int timeout)
         ssl_scache_dbm_store(s, &SCI);
 
 #ifdef SSL_VENDOR
-    ap_hook_use("ssl::vendor::scache_store", 
+    ap_hook_use("ap::mod_ssl::vendor::scache_store", 
                 AP_HOOK_SIG3(void,ptr,ptr), AP_HOOK_ALL, s, &SCI);
 #endif
 
@@ -141,7 +141,7 @@ SSL_SESSION *ssl_scache_retrieve(server_rec *s, UCHAR *id, int idlen)
         ssl_scache_dbm_retrieve(s, &SCI);
 
 #ifdef SSL_VENDOR
-    ap_hook_use("ssl::vendor::scache_retrieve", 
+    ap_hook_use("ap::mod_ssl::vendor::scache_retrieve", 
                 AP_HOOK_SIG3(void,ptr,ptr), AP_HOOK_ALL, s, &SCI);
 #endif
 
@@ -155,7 +155,7 @@ SSL_SESSION *ssl_scache_retrieve(server_rec *s, UCHAR *id, int idlen)
         if (mc->nSessionCacheMode == SSL_SCMODE_DBM)
             ssl_scache_dbm_remove(s, &SCI);
 #ifdef SSL_VENDOR
-        ap_hook_use("ssl::vendor::scache_remove", 
+        ap_hook_use("ap::mod_ssl::vendor::scache_remove", 
                     AP_HOOK_SIG3(void,ptr,ptr), AP_HOOK_ALL, s, &SCI);
 #endif
         return NULL;
@@ -183,7 +183,7 @@ void ssl_scache_remove(server_rec *s, SSL_SESSION *pSession)
         ssl_scache_dbm_remove(s, &SCI);
 
 #ifdef SSL_VENDOR
-    ap_hook_use("ssl::vendor::scache_remove", 
+    ap_hook_use("ap::mod_ssl::vendor::scache_remove", 
                 AP_HOOK_SIG3(void,ptr,ptr), AP_HOOK_ALL, s, &SCI);
 #endif
 
