@@ -7,21 +7,21 @@
 #   parameters
 make="$1"
 mflags="$2"
-ssleay="$3"
+openssl="$3"
 support="$4"
 type="$5"
 crt="$6"
 key="$7"
 
 #   we can operate only inside the Apache 1.3 source
-#   tree and only when mod_ssl+SSLeay is actually configured.
+#   tree and only when mod_ssl+OpenSSL is actually configured.
 if [ ! -f "../README.configure" ]; then
     echo "mkcert.sh:Error: Cannot operate outside the Apache 1.3 source tree." 1>&2
     echo "mkcert.sh:Hint:  You have to stay inside apache_1.3.x/src." 1>&2
     exit 1
 fi
-if [ ".$ssleay" = . ]; then
-    echo "mkcert.sh:Error: mod_ssl/SSLeay has to be configured before using this utility." 1>&2
+if [ ".$openssl" = . ]; then
+    echo "mkcert.sh:Error: mod_ssl/OpenSSL has to be configured before using this utility." 1>&2
     echo "mkcert.sh:Hint:  Configure mod_ssl with --enable-module=ssl in APACI, first." 1>&2
     exit 1
 fi
@@ -100,12 +100,12 @@ case $type in
         echo "${T_MD}RESULT: Server Certification Files${T_ME}"
         echo ""
         echo "o  ${T_MD}conf/ssl.key/server.key${T_ME}"
-        echo "   The PEM-encoded RSA private certificate file which you configure"
+        echo "   The PEM-encoded RSA private key file which you configure"
         echo "   with the 'SSLCertificateKeyFile' directive (automatically done"
         echo "   when you install via APACI). ${T_MD}KEEP THIS FILE PRIVATE!${T_ME}"
         echo ""
         echo "o  ${T_MD}conf/ssl.crt/server.crt${T_ME}"
-        echo "   The PEM-encoded X.509 server certificate file which you configure"
+        echo "   The PEM-encoded X.509 certificate file which you configure"
         echo "   with the 'SSLCertificateFile' directive (automatically done"
         echo "   when you install via APACI)."
         echo ""
@@ -124,12 +124,12 @@ case $type in
             touch $HOME/.rnd
         fi
         if [ ".$randfiles" != . ]; then
-            $ssleay genrsa -rand $randfiles \
-                           -out $sslkeydir/server.key \
-                           1024
+            $openssl genrsa -rand $randfiles \
+                            -out $sslkeydir/server.key \
+                            1024
         else
-            $ssleay genrsa -out $sslkeydir/server.key \
-                           1024
+            $openssl genrsa -out $sslkeydir/server.key \
+                            1024
         fi
         if [ $? -ne 0 ]; then
             echo "mkcert.sh:Error: Failed to generate RSA private key" 1>&2
@@ -162,10 +162,10 @@ emailAddress                    = "7. Email Address            (eg, name@FQDN)"
 emailAddress_max                = 40
 emailAddress_default            = www@snakeoil.dom
 EOT
-        $ssleay req -config .mkcert.cfg \
-                    -new \
-                    -key $sslkeydir/server.key \
-                    -out $sslcsrdir/server.csr
+        $openssl req -config .mkcert.cfg \
+                     -new \
+                     -key $sslkeydir/server.key \
+                     -out $sslcsrdir/server.csr
         if [ $? -ne 0 ]; then
             echo "mkcert.sh:Error: Failed to generate certificate signing request" 1>&2
             exit 1
@@ -184,12 +184,12 @@ EOT
         if [ ! -f .mkcert.serial ]; then
             echo '01' >.mkcert.serial
         fi
-        $ssleay x509 -days 365 \
-                     -CAserial .mkcert.serial \
-                     -CA $sslcrtdir/snakeoil-ca.crt \
-                     -CAkey $sslkeydir/snakeoil-ca.key \
-                     -in $sslcsrdir/server.csr -req \
-                     -out $sslcrtdir/server.crt
+        $openssl x509 -days 365 \
+                      -CAserial .mkcert.serial \
+                      -CA $sslcrtdir/snakeoil-ca.crt \
+                      -CAkey $sslkeydir/snakeoil-ca.key \
+                      -in $sslcsrdir/server.csr -req \
+                      -out $sslcrtdir/server.crt
         if [ $? -ne 0 ]; then
             echo "mkcert.sh:Error: Failed to generate X.509 certificate" 1>&2
             exit 1
@@ -219,14 +219,14 @@ EOT
             rm -f $sslcrtdir/server.crt.fixed
         fi
         echo "Verify: matching certificate & key modulus"
-        modcrt=`$ssleay x509 -noout -modulus -in $sslcrtdir/server.crt`
-        modkey=`$ssleay rsa  -noout -modulus -in $sslkeydir/server.key`
+        modcrt=`$openssl x509 -noout -modulus -in $sslcrtdir/server.crt`
+        modkey=`$openssl rsa  -noout -modulus -in $sslkeydir/server.key`
         if [ ".$modcrt" != ".$modkey" ]; then
             echo "mkcert.sh:Error: Failed to verify modulus on resulting X.509 certificate" 1>&2
             exit 1
         fi
         echo "Verify: matching certificate signature"
-        $ssleay verify -CAfile $sslcrtdir/snakeoil-ca.crt $sslcrtdir/server.crt
+        $openssl verify -CAfile $sslcrtdir/snakeoil-ca.crt $sslcrtdir/server.crt
         if [ $? -ne 0 ]; then
             echo "mkcert.sh:Error: Failed to verify signature on resulting X.509 certificate" 1>&2
             exit 1
@@ -250,9 +250,9 @@ EOT
             fi
         done
         if [ ".$rc" = .y ]; then
-            $ssleay rsa -des3 \
-                        -in  $sslkeydir/server.key \
-                        -out $sslkeydir/server.key.crypt
+            $openssl rsa -des3 \
+                         -in  $sslkeydir/server.key \
+                         -out $sslkeydir/server.key.crypt
             if [ $? -ne 0 ]; then
                 echo "mkcert.sh:Error: Failed to encrypt RSA private key" 1>&2
                 exit 1
@@ -269,12 +269,12 @@ EOT
         echo "${T_MD}RESULT: Server Certification Files${T_ME}"
         echo ""
         echo "o  ${T_MD}conf/ssl.key/server.key${T_ME}"
-        echo "   The PEM-encoded RSA private certificate file which you configure"
+        echo "   The PEM-encoded RSA private key file which you configure"
         echo "   with the 'SSLCertificateKeyFile' directive (automatically done"
         echo "   when you install via APACI). ${T_MD}KEEP THIS FILE PRIVATE!${T_ME}"
         echo ""
         echo "o  ${T_MD}conf/ssl.crt/server.crt${T_ME}"
-        echo "   The PEM-encoded X.509 server certificate file which you configure"
+        echo "   The PEM-encoded X.509 certificate file which you configure"
         echo "   with the 'SSLCertificateFile' directive (automatically done"
         echo "   when you install via APACI)."
         echo ""
@@ -299,12 +299,12 @@ EOT
             touch $HOME/.rnd
         fi
         if [ ".$randfiles" != . ]; then
-            $ssleay genrsa -rand $randfiles \
-                           -out $sslkeydir/ca.key \
-                           1024
+            $openssl genrsa -rand $randfiles \
+                            -out $sslkeydir/ca.key \
+                            1024
         else
-            $ssleay genrsa -out $sslkeydir/ca.key \
-                           1024
+            $openssl genrsa -out $sslkeydir/ca.key \
+                            1024
         fi
         if [ $? -ne 0 ]; then
             echo "mkcert.sh:Error: Failed to generate RSA private key" 1>&2
@@ -337,10 +337,10 @@ emailAddress                    = "7. Email Address            (eg, name@FQDN)"
 emailAddress_max                = 40
 emailAddress_default            = ca@snakeoil.dom
 EOT
-        $ssleay req -config .mkcert.cfg \
-                    -new \
-                    -key $sslkeydir/ca.key \
-                    -out $sslcsrdir/ca.csr
+        $openssl req -config .mkcert.cfg \
+                     -new \
+                     -key $sslkeydir/ca.key \
+                     -out $sslcsrdir/ca.csr
         if [ $? -ne 0 ]; then
             echo "mkcert.sh:Error: Failed to generate certificate signing request" 1>&2
             exit 1
@@ -356,10 +356,10 @@ EOT
         else
             certversion=1
         fi
-        $ssleay x509 -days 365 \
-                     -signkey $sslkeydir/ca.key \
-                     -in      $sslcsrdir/ca.csr -req \
-                     -out     $sslcrtdir/ca.crt
+        $openssl x509 -days 365 \
+                      -signkey $sslkeydir/ca.key \
+                      -in      $sslcsrdir/ca.csr -req \
+                      -out     $sslcrtdir/ca.crt
         if [ $? -ne 0 ]; then
             echo "mkcert.sh:Error: Failed to generate self-signed CA certificate" 1>&2
             exit 1
@@ -380,14 +380,14 @@ EOT
             rm -f $sslcrtdir/ca.crt.fixed
         fi
         echo "Verify: matching certificate & key modulus"
-        modcrt=`$ssleay x509 -noout -modulus -in $sslcrtdir/ca.crt`
-        modkey=`$ssleay rsa  -noout -modulus -in $sslkeydir/ca.key`
+        modcrt=`$openssl x509 -noout -modulus -in $sslcrtdir/ca.crt`
+        modkey=`$openssl rsa  -noout -modulus -in $sslkeydir/ca.key`
         if [ ".$modcrt" != ".$modkey" ]; then
             echo "mkcert.sh:Error: Failed to verify modulus on resulting X.509 certificate" 1>&2
             exit 1
         fi
         echo "Verify: matching certificate signature"
-        $ssleay verify $sslcrtdir/ca.crt
+        $openssl verify $sslcrtdir/ca.crt
         if [ $? -ne 0 ]; then
             echo "mkcert.sh:Error: Failed to verify signature on resulting X.509 certificate" 1>&2
             exit 1
@@ -399,12 +399,12 @@ EOT
             touch $HOME/.rnd
         fi
         if [ ".$randfiles" != . ]; then
-            $ssleay genrsa -rand $randfiles \
-                           -out $sslkeydir/server.key \
-                           1024
+            $openssl genrsa -rand $randfiles \
+                            -out $sslkeydir/server.key \
+                            1024
         else
-            $ssleay genrsa -out $sslkeydir/server.key \
-                           1024
+            $openssl genrsa -out $sslkeydir/server.key \
+                            1024
         fi
         if [ $? -ne 0 ]; then
             echo "mkcert.sh:Error: Failed to generate RSA private key" 1>&2
@@ -437,10 +437,10 @@ emailAddress                    = "7. Email Address            (eg, name@fqdn)"
 emailAddress_max                = 40
 emailAddress_default            = www@snakeoil.dom
 EOT
-        $ssleay req -config .mkcert.cfg \
-                    -new \
-                    -key $sslkeydir/server.key \
-                    -out $sslcsrdir/server.csr
+        $openssl req -config .mkcert.cfg \
+                     -new \
+                     -key $sslkeydir/server.key \
+                     -out $sslcsrdir/server.csr
         if [ $? -ne 0 ]; then
             echo "mkcert.sh:Error: Failed to generate certificate signing request" 1>&2
             exit 1
@@ -459,12 +459,12 @@ EOT
         if [ ! -f .mkcert.serial ]; then
             echo '01' >.mkcert.serial
         fi
-        $ssleay x509 -days 365 \
-                     -CAserial .mkcert.serial \
-                     -CA    $sslcrtdir/ca.crt \
-                     -CAkey $sslkeydir/ca.key \
-                     -in    $sslcsrdir/server.csr -req \
-                     -out   $sslcrtdir/server.crt
+        $openssl x509 -days 365 \
+                      -CAserial .mkcert.serial \
+                      -CA    $sslcrtdir/ca.crt \
+                      -CAkey $sslkeydir/ca.key \
+                      -in    $sslcsrdir/server.csr -req \
+                      -out   $sslcrtdir/server.crt
         if [ $? -ne 0 ]; then
             echo "mkcert.sh:Error: Failed to generate X.509 certificate" 1>&2
             exit 1
@@ -493,14 +493,14 @@ EOT
             rm -f $sslcrtdir/server.crt.fixed
         fi
         echo "Verify: matching certificate & key modulus"
-        modcrt=`$ssleay x509 -noout -modulus -in $sslcrtdir/server.crt`
-        modkey=`$ssleay rsa  -noout -modulus -in $sslkeydir/server.key`
+        modcrt=`$openssl x509 -noout -modulus -in $sslcrtdir/server.crt`
+        modkey=`$openssl rsa  -noout -modulus -in $sslkeydir/server.key`
         if [ ".$modcrt" != ".$modkey" ]; then
             echo "mkcert.sh:Error: Failed to verify modulus on resulting X.509 certificate" 1>&2
             exit 1
         fi
         echo "Verify: matching certificate signature"
-        $ssleay verify -CAfile $sslcrtdir/ca.crt $sslcrtdir/server.crt
+        $openssl verify -CAfile $sslcrtdir/ca.crt $sslcrtdir/server.crt
         if [ $? -ne 0 ]; then
             echo "mkcert.sh:Error: Failed to verify signature on resulting X.509 certificate" 1>&2
             exit 1
@@ -524,9 +524,9 @@ EOT
             fi
         done
         if [ ".$rc" = .y ]; then
-            $ssleay rsa -des3 \
-                        -in  $sslkeydir/ca.key \
-                        -out $sslkeydir/ca.key.crypt
+            $openssl rsa -des3 \
+                         -in  $sslkeydir/ca.key \
+                         -out $sslkeydir/ca.key.crypt
             if [ $? -ne 0 ]; then
                 echo "mkcert.sh:Error: Failed to encrypt RSA private key" 1>&2
                 exit 1
@@ -557,9 +557,9 @@ EOT
             fi
         done
         if [ ".$rc" = .y ]; then
-            $ssleay rsa -des3 \
-                        -in  $sslkeydir/server.key \
-                        -out $sslkeydir/server.key.crypt
+            $openssl rsa -des3 \
+                         -in  $sslkeydir/server.key \
+                         -out $sslkeydir/server.key.crypt
             if [ $? -ne 0 ]; then
                 echo "mkcert.sh:Error: Failed to encrypt RSA private key" 1>&2
                 exit 1
@@ -573,30 +573,30 @@ EOT
         fi
         echo "______________________________________________________________________"
         echo ""
-        echo "${T_MD}RESULT: Server and CA Certification Files${T_ME}"
+        echo "${T_MD}RESULT: CA and Server Certification Files${T_ME}"
         echo ""
         echo "o  ${T_MD}conf/ssl.key/ca.key${T_ME}"
-        echo "   The PEM-encoded RSA private certificate file of the CA which you can"
+        echo "   The PEM-encoded RSA private key file of the CA which you can"
         echo "   use to sign other servers or clients. ${T_MD}KEEP THIS FILE PRIVATE!${T_ME}"
         echo ""
         echo "o  ${T_MD}conf/ssl.crt/ca.crt${T_ME}"
-        echo "   The PEM-encoded X.509 CA server certificate file which you use to"
+        echo "   The PEM-encoded X.509 certificate file of the CA which you use to"
         echo "   sign other servers or clients. When you sign clients with it (for"
         echo "   SSL client authentication) you can configure this file with the"
         echo "   'SSLCACertificateFile' directive."
         echo ""
         echo "o  ${T_MD}conf/ssl.key/server.key${T_ME}"
-        echo "   The PEM-encoded RSA private certificate file which you configure"
+        echo "   The PEM-encoded RSA private key file of the server which you configure"
         echo "   with the 'SSLCertificateKeyFile' directive (automatically done"
         echo "   when you install via APACI). ${T_MD}KEEP THIS FILE PRIVATE!${T_ME}"
         echo ""
         echo "o  ${T_MD}conf/ssl.crt/server.crt${T_ME}"
-        echo "   The PEM-encoded X.509 server certificate file which you configure"
+        echo "   The PEM-encoded X.509 certificate file of the server which you configure"
         echo "   with the 'SSLCertificateFile' directive (automatically done"
         echo "   when you install via APACI)."
         echo ""
         echo "o  ${T_MD}conf/ssl.csr/server.csr${T_ME}"
-        echo "   The PEM-encoded X.509 certificate signing request file which" 
+        echo "   The PEM-encoded X.509 certificate signing request of the server file which" 
         echo "   you can send to an official Certificate Authority (CA) in order"
         echo "   to request a real server certificate (signed by this CA instead"
         echo "   of our own CA) which later can replace the conf/ssl.crt/server.crt"
@@ -633,7 +633,7 @@ EOT
             sed -e '/-----BEGIN RSA PRIVATE KEY/,/-----END RSA PRIVATE KEY/p' -e '/.*/d' \
                 <$key >$sslkeydir/server.key
         fi
-        $ssleay x509 -noout -in $sslcrtdir/server.crt
+        $openssl x509 -noout -in $sslcrtdir/server.crt
         if [ $? -ne 0 ]; then
             echo "mkcert.sh:Error: Failed to check certificate contents: $crt" 1>&2
             exit 1
@@ -641,12 +641,12 @@ EOT
         echo "${T_MD}RESULT: Server Certification Files${T_ME}"
         echo ""
         echo "o  ${T_MD}conf/ssl.key/server.key${T_ME}"
-        echo "   The PEM-encoded RSA private certificate file which you configure"
+        echo "   The PEM-encoded RSA private key file which you configure"
         echo "   with the 'SSLCertificateKeyFile' directive (automatically done"
         echo "   when you install via APACI). ${T_MD}KEEP THIS FILE PRIVATE!${T_ME}"
         echo ""
         echo "o  ${T_MD}conf/ssl.crt/server.crt${T_ME}"
-        echo "   The PEM-encoded X.509 server certificate file which you configure"
+        echo "   The PEM-encoded X.509 certificate file which you configure"
         echo "   with the 'SSLCertificateFile' directive (automatically done"
         echo "   when you install via APACI)."
         echo ""
